@@ -1,10 +1,11 @@
 '''Managing work units.'''
-import traceback
 import os
 import os.path
 import shutil
+import traceback
 
 from seesaw.event import Event
+import seesaw.six
 
 
 class Item(object):
@@ -15,11 +16,12 @@ class Item(object):
     An Item behaves like a mutable mapping.
 
     .. note::
-        State belonging to a item should be stored on the actual item 
+        State belonging to a item should be stored on the actual item
         itself. That is, do not store variables onto a :class:`Task` unless
         you know what you are doing.
     '''
-    def __init__(self, pipeline, item_id, item_number, properties=None, keep_data=False):
+    def __init__(self, pipeline, item_id, item_number, properties=None,
+                 keep_data=False, prepare_data_directory=True):
         self.pipeline = pipeline
         self.item_id = item_id
         self.item_number = item_number
@@ -30,6 +32,7 @@ class Item(object):
         self.canceled = False
         self.completed = False
         self.failed = False
+        self.finished = False
         self._errors = []
         self._last_output = ""
         self.task_status = {}
@@ -43,7 +46,8 @@ class Item(object):
         self.on_fail = Event()
         self.on_finish = Event()
 
-        self.prepare_data_directory()
+        if prepare_data_directory:
+            self.prepare_data_directory()
 
     def prepare_data_directory(self):
         dirname = os.path.join(self.pipeline.data_dir, self.item_id)
@@ -59,8 +63,15 @@ class Item(object):
                 shutil.rmtree(dirname)
 
     def log_output(self, data, full_line=True):
+        if isinstance(data, seesaw.six.binary_type):
+            try:
+                data = data.decode('utf8', 'replace')
+            except UnicodeError:
+                data = data.decode('ascii', 'replace')
+
         if full_line and len(data) > 0:
-            if data[0] != "\n" and len(self._last_output) > 0 and self._last_output[-1] != "\n":
+            if data[0] != "\n" and len(self._last_output) > 0 and \
+                    self._last_output[-1] != "\n":
                 data = "\n" + data
             if data[-1] != "\n":
                 data = data + "\n"
@@ -81,6 +92,7 @@ class Item(object):
             self.on_task_status(self, task, status, old_status)
 
     def cancel(self):
+        assert not self.canceled
         self.clear_data_directory()
         self.canceled = True
         self.finished = True
@@ -88,6 +100,7 @@ class Item(object):
         self.on_finish(self)
 
     def complete(self):
+        assert not self.completed
         self.clear_data_directory()
         self.completed = True
         self.finished = True
@@ -95,6 +108,7 @@ class Item(object):
         self.on_finish(self)
 
     def fail(self):
+        assert not self.failed
         self.clear_data_directory()
         self.failed = True
         self.finished = True
@@ -102,7 +116,11 @@ class Item(object):
         self.on_finish(self)
 
     def description(self):
-        return "Item %s" % (self.properties["item_name"] if "item_name" in self.properties else "")
+        return "Item %s" % (self.properties["item_name"]
+                            if "item_name" in self.properties else "")
+
+    def get(self, key):
+        return self.properties.get(key)
 
     def __contains__(self, key):
         return key in self.properties
@@ -128,7 +146,8 @@ class Item(object):
             for e in err[1]:
                 # TODO this isn't how exceptions work?
                 if isinstance(e, Exception):
-                    s += "%s\n" % traceback.format_exception(Exception, e, None)
+                    s += "%s\n" % traceback.format_exception(Exception, e,
+                                                             None)
                 else:
                     s += "%s\n" % str(e)
             s += "\n  " + str(err)
@@ -151,7 +170,7 @@ class ItemValue(object):
     def fill(self, item, value):
         if isinstance(self, ItemValue):
             item[self.key] = value
-        elif self == None:
+        elif self is None:
             pass
         else:
             raise Exception("Attempting to fill " + str(type(self)))
